package com.steerinfo.dil.controller;
import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.service.ITmstruckUnloadResultService;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.DataChange;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.collections4.Put;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.text.SimpleDateFormat;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


/**
 * TmstruckQualityTrackingCard RESTful接口：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-09-09 05:44
 * 类描述
 * 修订历史：
 * 日期：2021-09-09
 * 作者：generator
 * 参考：
 * 描述：TmstruckQualityTrackingCard RESTful接口
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@RestController
@RequestMapping("/${api.version}/tmstruckunloadresult")
public class TmstruckUnloadResultController extends BaseRESTfulController {

    @Autowired
    ITmstruckUnloadResultService tmstruckUnloadResultService;

    @Autowired
    ESFeign esFeign;

    @Autowired
    ColumnDataUtil columnDataUtil;

    private final SimpleDateFormat sdfDateTime = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
    @ApiOperation(value="查询卸货实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(103)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getUnloadResult")
    public RESTfulResult getUnloadResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                           Integer apiId,
                                           Integer pageNum,
                                           Integer pageSize,
                                           Integer orderType,
                                           String con,
                                           String userId,
                                           String  userIds,
                                           String startTime,
                                           String endTime

    ){
        DataChange.queryDataByDateTime(startTime, endTime, mapValue, sdfDateTime);//根据时间段查询数据
        if (orderType!=null){
            mapValue.put("orderTypee", orderType);
        }
        if(con !=null &&!"null".equals(con)){
            mapValue.put("con",con);
        }
        if (userId!=null){
            mapValue.put("userId",userId);
        }
        if (userIds!=null){
            mapValue.put("userIds",userIds);
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue,sdfDateTime);//根据时间段查询数据
        PageHelper.startPage(pageNum,pageSize);
        //分页数据
        List<Map<String, Object>> unloadResult = tmstruckUnloadResultService.getUnloadResult(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null,unloadResult);
        return success(pageList);
    }


    @ApiOperation(value="更新卸货实绩 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "resultId", value = "装车作业实绩ID", required = false, dataType = "Integer"),
    })
    @PostMapping("/updateUnloadResult")
    public RESTfulResult updateUnloadResult(@RequestBody Map<String, Object> mapValue) throws Exception {
        int i = tmstruckUnloadResultService.updateUnloadResult(mapValue);
        if(i > 0){
            return success("卸货成功！");
        }else if(i == -2){
            return failed("已卸过此物资");
        }else if(i == -3){
            return failed("该订单没有卸货作业");
        }else if( i == -6) {
            return failed("请通知司机完成前序操作再来卸货！");
        }else if (i==-4){
            return failed("委托发送失败,无法卸货");
        }
        else{
            return failed("卸货失败，请联系管理员！");
        }
    }


    @ApiOperation(value="新增卸货实绩：远程调用")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "总实绩ID、卸货点", required = false, dataType = "Map"),
    })
    @PostMapping("/addUnloadResult")
    public RESTfulResult addUnloadResult(@RequestBody(required=false) Map<String, Object> mapValue){
        int i = tmstruckUnloadResultService.addUnloadResult(mapValue);
        return success(i);
    }
//*******************************************内转物流**************************************************
    /**
     *  内转物流卸货装车实绩
     * @param map
     * @return
     */
    @ApiOperation(value="内转物流新增卸货实绩 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderNumber", value = "运输订单号", required = false, dataType = "String"),
    })
    @PostMapping("/addUnLoadResultForconverted")
    public RESTfulResult addUnLoadResultForconverted(@RequestBody(required = false) Map<String,Object> map){
        String orderNumber=(String)map.get("orderNumber");
        Map<String,Object> loadResultIdForOrderNumber = tmstruckUnloadResultService.selectLoadResultIdByOrderNumber(orderNumber);
        Integer loadResultId =(Integer) loadResultIdForOrderNumber.get("loadResultId");
        //通过运输订单号查找实绩是否存在
        int i=0;
        int i1=0;
        int i2=0;
        if (loadResultId==null){
            //执行新增
            i=tmstruckUnloadResultService.addUnloadresultForconverted(map);
            //然后执行更新
            i1=tmstruckUnloadResultService.updateUnloadresultForconverted(map);
        }
        else {
            i2=tmstruckUnloadResultService.updateUnloadresultForconverted(map);
        }
        return  success(i+i1+i2);
    }
}
