package com.steerinfo.dil.feign;

import com.steerinfo.framework.controller.RESTfulResult;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * @author luobang
 * @create 2021-09-17 14:13
 */
@FeignClient(value = "DAL-DAZHOU-WMS-DEV",url = "${openfeign.WMSFeign.url}")
public interface WMSFeign {
    /**
     * 钢材入库实绩
     * @param mapValue
     * @param apiId
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/inboundResult/getWmsInboundResult",method = RequestMethod.POST)
    Map<String,Object> getWmsInboundResult(@RequestBody(required = false) Map<String, Object> mapValue,
                                           @RequestParam Integer apiId,
                                           @RequestParam Integer pageNum,
                                           @RequestParam Integer pageSize);

    /**
     * 展示出库实绩
     * @param apiId
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/wmspoutboundresults/getWmspOutboundResult",method = RequestMethod.POST)
    Map<String,Object> getWmspOutboundResult(@RequestBody(required = false)
                                             @RequestParam Integer apiId,
                                             @RequestParam Integer pageNum,
                                             @RequestParam Integer pageSize);

    /**
     * 新增出库实绩
     * @param mapval
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/wmspoutboundresults/insertWmspOutBoundResult",method = RequestMethod.POST)
    Map<String,Object> insertWmspOutBoundResult(@RequestBody(required = false) Map<String, Object> mapval);

    /**
     * 新增出库扫描实绩
     * @param mapval
     * @return
     */
    @PostMapping(value = "/api/v1/wms/wmspoutboundscanresults/insertWmspOutboundScanResult")
    Map<String,Object> insertWmspOutboundScanResult(@RequestBody(required = false) Map<String, Object> mapval);

    /**
     * 更新出库状态
     * @param resultId
     * @return
     */
    @PostMapping(value = "/api/v1/wms/wmspoutboundresults/updataResultStatus")
    Map<String,Object> updataResultStatus(@RequestBody(required = false) Integer resultId);

    @PostMapping(value = "/api/v1/wms/wmsoffsitelibaryoutbounds/getRmsMaterial")
    Map<String,Object> getRmsMaterial(@RequestBody(required = false) Map<String, Object> mapval);

    /**
     *  展示实时库存数据
     * @param apiId
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/wmspgridmaterials/selectGridMaterialList",method = RequestMethod.POST)
    Map<String,Object> selectGridMaterialList(@RequestBody(required = false)
                                              @RequestParam Integer apiId,
                                              @RequestParam Integer pageNum,
                                              @RequestParam Integer pageSize);

    /**
     * 钢材异地库出库扫描
     * @param map
     * @return
     */
    @PostMapping(value = "/api/v1/wms/wmsoffsitelibaryoutbounds/OutScanResultTag")
    Map<String,Object> OutScanResultTag(@RequestBody(required = false) Map<String, Object> map);

    /**
     * 获取钢材异地库出库数据
     * @param apiId
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/wmsoffsitelibaryoutbounds/getWmsOffsiteLibaryOutboundList",method = RequestMethod.POST)
    Map<String,Object> getWmsOffsiteLibaryOutboundList(@RequestBody(required = false)
                                                       @RequestParam Integer apiId,
                                                       @RequestParam Integer pageNum,
                                                       @RequestParam Integer pageSize);

    /**
     * 展示钢材异地库入库实绩表
     * @param apiId
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/wmsoffsitelibraryinbounds/getWmsOffsiteLibaryInboundList",method = RequestMethod.POST)
    Map<String,Object> getWmsOffsiteLibaryInboundList(@RequestBody(required = false)
                                                      @RequestParam Integer apiId,
                                                      @RequestParam Integer pageNum,
                                                      @RequestParam Integer pageSize);

    /**
     *   钢材异地库入库扫描新增异地库入库实绩
     * @param map
     * @return
     */
    @PostMapping(value = "/api/v1/wms/wmsoffsitelibraryinbounds/insertOffsiteLibraryInbound")
    Map<String,Object> insertOffsiteLibraryInbound(@RequestBody(required = false) Map<String, Object> map);

    /**
     *  //展示在途库存列表
     * @param apiId
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/wmspintransitinventorys/getWmspIntransitInventory",method = RequestMethod.POST)
    Map<String,Object> getWmspIntransitInventory(@RequestBody(required = false)
                                                 @RequestParam Integer apiId,
                                                 @RequestParam Integer pageNum,
                                                 @RequestParam Integer pageSize);


    /**
     *新增倒库出库实绩
     * @param map
     * @return
     */
    @PostMapping(value = "/api/v1/wms/wmspoutboundresults/insertOutBoundResult")
    Map<String,Object> insertOutBoundResult(@RequestBody(required = false) Map<String, Object> map);

    /**
     * //新增倒库出库扫描实绩
     * @param mapval
     * @return
     */
    @PostMapping(value = "/api/v1/wms/wmspoutboundscanresults/AddWmspOutboundScanResult")
    Map<String,Object> AddWmspOutboundScanResult(@RequestBody(required = false) Map<String, Object> mapval);

    /**
     * 通过下拉框筛选数据
     * @param apiId
     * @param pageNum
     * @param pageSize
     * @param warehouseid
     * @param gradtionNumber
     * @param stackingId
     * @return
     */
    @PostMapping(value = "/api/v1/wms/wmsprestackmakeresults/getWmspRestackMakeResultList")
    Map<String,Object> getWmspRestackMakeResultList(@RequestBody(required = false)
                                                    @RequestParam Integer apiId,
                                                    @RequestParam Integer pageNum,
                                                    @RequestParam Integer pageSize,
                                                    @RequestParam Integer warehouseid,
                                                    @RequestParam Integer gradtionNumber,
                                                    @RequestParam Integer stackingId);

    /**
     *    添加倒垛单实绩
     * @param mapval
     * @return
     */
    @PostMapping(value = "/api/v1/wms/wmsprestackmakeresults/addRestackMakeResult")
    Map<String,Object> addRestackMakeResult(@RequestBody(required = false) Map<String, Object> mapval);

    /**
     *   删除倒垛单
     * @param resultId
     * @return
     */
    @PostMapping(value = "/api/v1/wms/wmsprestackmakeresults/deleteByResultId/{resultId}")
    Map<String,Object> deleteByResultId(@PathVariable Integer resultId);

    /**
     * 下发倒垛单pc端
     * @param resultId
     * @return
     */
    @PostMapping(value = "/api/v1/wms/wmsprestackmakeresults/dispatchDistrubtionStatus/{resultId}")
    Map<String,Object> dispatchDistrubtionStatus(@PathVariable Integer resultId);

    /**
     * 下拉框获取层次
     * @param warehouseid
     * @param stackingId
     * @return
     */
    @PostMapping(value = "/api/v1/wms/wmsprestackmakeresults/selectGardationNumber")
    Map<String,Object> selectGardationNumber(@RequestParam Integer warehouseid,
                                             @RequestParam Integer stackingId);

    /**
     *   下拉框获取垛位
     * @param warehouseid
     * @return
     */
    @PostMapping(value = "/api/v1/wms/wmsprestackmakeresults/selectStackingId")
    Map<String,Object> selectStackingId(@RequestParam Integer warehouseid);

    /**
     * 下拉框获取仓库名称
     * @return
     */
    @PostMapping(value = "/api/v1/wms/wmsprestackmakeresults/selectWarehouse")
    Map<String,Object> selectWarehouse();

    /**
     *展示倒垛单
     * @param apiId
     * @param pageNum
     * @param pageSize
     * @param DistrubtionStatus
     * @return
     */
   @PostMapping(value = "/api/v1/wms/wmsprestackmakeresults/selectRestackList")
   Map<String,Object> selectRestackList(@RequestBody(required = false)
                                        @RequestParam Integer apiId,
                                        @RequestParam Integer pageNum,
                                        @RequestParam Integer pageSize,
                                        @RequestParam Integer DistrubtionStatus
   );
    /**
     *  修改倒垛单
     * @param mapval
     * @return
     */
   @PostMapping(value = "/api/v1/wms/wmsprestackmakeresults/editRestackMakeResult")
   Map<String,Object> editRestackMakeResult(@RequestBody(required = false) Map<String, Object> mapval);
    /**
     *   渲染倒垛后的仓库信息
     * @param resultId
     * @return
     */
  @PostMapping(value = "/api/v1/wms/wmsprestackmakeresults/selectAfterWarehouseByResultId/{resultId}")
  Map<String,Object> selectAfterWarehouseByResultId(@PathVariable Integer resultId);
    /**
     *  渲染倒垛后的垛位信息
     * @param resultId
     * @return
     */
  @PostMapping(value = "/api/v1/wms/wmsprestackmakeresults/selectAfterstackingByResultId/{resultId}")
  Map<String,Object> selectAfterstackingByResultId(@PathVariable Integer resultId);

    /**
     * PDA展示倒垛单
     * @param map
     * @return
     */
  @PostMapping(value = "/api/v1/wms/wmsprestackmakeresults/selectRestackForPDA")
  Map<String,Object> selectRestackForPDA(@RequestBody(required = false) Map<String, Object> map);
    /**
     * PDA根据实绩id查找物资信息
     * @param map
     * @return
     */
  @PostMapping(value = "/api/v1/wms/wmsprestackmakeresults/selectMaterialInfoByResultId")
  Map<String,Object> selectMaterialInfoByResultId(@RequestBody(required = false) Map<String, Object> map);
    /**
     * PDA根据仓库id查找倒垛单
     * @param map
     * @return
     */
    @PostMapping(value = "/api/v1/wms/wmsprestackmakeresults/selectRestackByWarehouseId")
    Map<String,Object> selectRestackByWarehouseId(@RequestBody(required = false) Map<String, Object> map);
    /**
     * 库管员扫描吊牌添加扫描实绩
     * @param mal
     * @return
     */
   @PostMapping(value = "/api/v1/wms/wmsprestackscanresults/ScanTagResult")
   Map<String,Object> ScanTagResult(@RequestBody(required = false) Map<String, Object> mal);
    /**
     * 库管员下发倒垛单
     * @param mapList
     * @return
     */
  @PostMapping(value = "/api/v1/wms/wmsprestackscanresults/Issue")
  Map<String,Object> Issue(@RequestBody(required = false) List<Map<String, Object>> mapList);
    /**
     * 展示退库实绩
     * @param mapValue
     * @param apiId
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/inboundResult/getWmsReboundResult",method = RequestMethod.POST)
    RESTfulResult getWmsReboundResult(@RequestBody(required = false) Map<String, Object> mapValue,
                                      @RequestParam Integer apiId,
                                      @RequestParam Integer pageNum,
                                      @RequestParam Integer pageSize);

    /**
     * 展示倒库实绩
     * @param mapValue
     * @param apiId
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/inboundResult/getWmsIvboundResult",method = RequestMethod.POST)
    RESTfulResult getWmsIvboundResult(@RequestBody(required = false) Map<String, Object> mapValue,
                                      @RequestParam Integer apiId,
                                      @RequestParam Integer pageNum,
                                      @RequestParam Integer pageSize);


    /**
     * 展示倒库物资实绩
     * @param mapValue
     * @param apiId
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/inboundScanResult/getWmsIvboundMaterial",method = RequestMethod.POST)
    RESTfulResult getWmsIvboundMaterial(@RequestBody(required = false) Map<String, Object> mapValue,
                                        @RequestParam Integer apiId,
                                        @RequestParam Integer pageNum,
                                        @RequestParam Integer pageSize);

    /**
     * 库存盘点实绩
     */
    @RequestMapping(value = "/api/v1/wms/inventoryCheck/getInventoryCheck",method = RequestMethod.POST)
    RESTfulResult getInventoryCheck(@RequestBody(required = false) Map<String, Object> mapValue,
                                    @RequestParam Integer apiId,
                                    @RequestParam Integer pageNum,
                                    @RequestParam Integer pageSize);


    /**
     * 库存结转
     * @param mapValue
     * @param apiId
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/inventoryClose/getInventoryClose",method = RequestMethod.POST)
    RESTfulResult getInventoryClose(@RequestBody(required = false) Map<String, Object> mapValue,
                                    @RequestParam Integer apiId,
                                    @RequestParam Integer pageNum,
                                    @RequestParam Integer pageSize);

    /**
     * 收发存报表
     */
    @RequestMapping(value = "/api/v1/wms/sendReceive/getSendReceive",method = RequestMethod.POST)
    RESTfulResult getSendReceive(@RequestBody(required = false) Map<String, Object> mapValue,
                                 @RequestParam Integer apiId,
                                 @RequestParam Integer pageNum,
                                 @RequestParam Integer pageSize);

    /**
     * 展示未下发吊钢工扫描吊牌实绩
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/inboundScanResult/getTagResult",method = RequestMethod.POST)
    Map<String,Object>  getTagResult();

    /**
     * 展示已入库吊钢工扫描吊牌实绩
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/inboundScanResult/getIssuedTagResult",method = RequestMethod.POST)
    Map<String,Object>  getIssuedTagResult();

    /**
     * 展示异常入库吊钢工扫描吊牌实绩
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/inboundScanResult/getIssuedTagNoResult",method = RequestMethod.POST)
    Map<String,Object>  getIssuedTagNoResult();

    /**
     * 展示退库已下发吊钢工扫描吊牌实绩
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/inboundScanResult/getReIssuedResult",method = RequestMethod.POST)
    Map<String,Object>  getIssuedResult();

    /**
     * 展示未下发退库吊钢工扫描吊牌实绩
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/inboundScanResult/getReTagResult",method = RequestMethod.POST)
    Map<String,Object>  getReTagResult();

    /**
     * 展示已倒库入库吊钢工扫描吊牌实绩
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/inboundScanResult/getIvIssuedResult",method = RequestMethod.POST)
    Map<String,Object>  getIvIssuedResult();

    /**
     * 展示倒库入库未下发退库吊钢工扫描吊牌实绩
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/inboundScanResult/getIvTagResult",method = RequestMethod.POST)
    Map<String,Object>  getIvTagResult();

    /**
     * 新增入库实绩，返回选择垛位
     * @param mapList
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/inboundResult/insertInboundResult",method = RequestMethod.POST)
    String insertInboundResult(@RequestBody List<Map<String, Object>> mapList);

    /**
     * 新增退库实绩，返回选择垛位
     * @param mapList
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/inboundResult/insertReboundResult",method = RequestMethod.POST)
    String insertReboundResult(@RequestBody List<Map<String, Object>> mapList);

    /**
     * 新增倒库入库实绩，返回选择垛位
     * @param mapList
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/inboundResult/insertIvboundResult",method = RequestMethod.POST)
    String insertIvboundResult(@RequestBody List<Map<String, Object>> mapList);
    /**
     * 行车工查看垛位
     * @param DriverId
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/inboundStack/getInboundStack",method = RequestMethod.POST)
    Integer  getInboundStack(@RequestParam Integer DriverId);


    /**
     * 新增库存盘点
     * @param map
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/inboundStack/getInboundStack",method = RequestMethod.POST)
    Map<String,Object>  inventoryCheck(@RequestBody Map<String, Object> map);


    /**
     * 新增入库扫描实绩
     * @param map
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/inboundScanResult/insertResult",method = RequestMethod.POST)
    Map<String, Object> insertResult(@RequestBody Map<String, Object> map);


    /**
     * 新增退库扫描实绩
     * @param map
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/inboundScanResult/insertReboundScanResult",method = RequestMethod.POST)
    Map<String, Object> insertReboundScanResult(@RequestBody Map<String, Object> map);


    /**
     *新增倒库入库扫描实绩
     * @param map
     * @return
     */
    @RequestMapping(value = "/api/v1/wms/inboundScanResult/insertIvboundScanResult",method = RequestMethod.POST)
    Map<String, Object> insertIvboundScanResult(@RequestBody Map<String, Object> map);
    /**
     * 根据实绩id查找物资是否稽核完成
     *
     */
    @PostMapping(value = "/api/vi/wms/wmsprestackscanresults/selectMaterialSteelIdByReusltId")
    Map<String, Object> selectMaterialSteelIdByReusltId(@RequestBody(required = false) Map<String, Object> map);
}

