package com.steerinfo.dil.mapper;

import com.steerinfo.dil.model.TmstruckLoadResult;
import com.steerinfo.framework.mapper.IBaseMapper;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Map;

@Mapper
public interface TmstruckLoadResultMapper extends IBaseMapper<TmstruckLoadResult, BigDecimal> {
    //查询采购装车实绩
    List<Map<String, Object>> getCGJKLoadResult(Map<String, Object> map);

    //查询销售装车实绩
    List<Map<String, Object>> getXSLoadResult(Map<String, Object> map);

    //查询内转钢材到异地库装车实绩
    List<Map<String, Object>> getSteelNzLoadResult(Map<String, Object> map);

    //查询内转进口矿/国产矿装车实绩
    List<Map<String, Object>> getImportedDomesticNzLoadResult(Map<String, Object> map);

    //查询内转厂内物资装车实绩
    List<Map<String, Object>> getInFactoryLoadResult(Map<String, Object> map);

    //查询最大ID值
    @Select("select seq_tmstruck_load_result.nextval from dual")
    BigDecimal selectMaxId();

    //通过Id获取装车实绩 数据 用于修改
    List<Map<String, Object>> getLoadResultById(Integer resultId);

    //通过发站ID查询所属港口ID
    BigDecimal getPortIdBySendStationId(BigDecimal sendStationId);

    //通过订单ID查询批次ID
    BigDecimal getBatchIdByOrderId(BigDecimal orderId);

    //通过订单Id 和物资ID 查询装车实绩Id  一个订单可能会有多个装车实绩
    Integer getLoadResultId(Map<String, Object> map);

    //根据运输订单号查找运输订单类型
    Integer selectOrderTypeByOrderNumber(String oderNumber);

    //根据运输订单号查找扫描实绩id
    List<Integer>  selectResultIdByOrderNumber(String orderNumber);

    //根据实绩id查找扫描时间
    Date selectLoadTimeByResultId(BigDecimal resultId);

    //根据实绩id查找扫描时间
    Integer selecLoadIdByresultId(Integer resultId);

    //销售查询所有的装车实绩
    List<Map<String,Object>> selectLoadResultForSale(Map<String,Object> map);

    //根据运输订单号查找物资id
    List<Map<String,Object>> selectMaterialIdByOrderNumber(Map<String, Object> map);

    //内转物流汽车装货展示
    List<Map<String,Object>> selectLoadResultForConverted(Map<String,Object> map);

    //通过实绩id渲染数据
    List<Map<String,Object>> selectLoadResultByResultId(Integer resultId);

    //通过车牌号查找物资id和运力id以及总实绩id
    Map<String,Object> selectMaterialIdAndCapacityId(String  capacityNumber);

    //根据运输订单号查找装车实绩
    Map<String,Object> selectLoadResultIdByOrderNumber(String orderNumber);

    //通过用户id查找用户姓名
    String selectPersonNameByPersonnelId(Integer personnelId);

    //通过物资id查找物资类型
    Integer selectMaterialTypeByMaterialId(Integer materialId);

    //通过港口ID查询仓库表中的港存库ID
    BigDecimal getWarehouseIdByPortId(BigDecimal portId);

    /*
    TangXiaoFeng
     */
    //通过物资ID和总实绩Id查询唯一的装车实绩Id
    Map<String, Object> getLoadResultIdByMIdAndTotalId(Map<String, Object> map);

    //通过物资ID和订单Id查询唯一的装车实绩Id
    Integer getLoadIdByOrderIdAndMId(Map<String, Object> map);

    //通过物资ID和运输订单号 查找最先扫描Id
    Map<String, Object> getMinScanIdByOrderNum(Map<String, Object> map);

    //通过物资唯一编码 查找物资ID
    BigDecimal getMaterialIdByMaterialCode(String materialOnlyCode);

    //查询所有正在进行进厂排队的销售订单
    List<Map<String, Object>> getSaleOrderOnQueue(Map<String, Object> map);


    //根据总实绩查询装车实绩
    BigDecimal getResultId(BigDecimal totalId);

    //根据总实绩id查询运输订单类型
    Integer getOrderType(BigDecimal totalId);

    //根据运输id查询所有的零星物资装车实绩
    List<Map<String, Object>> getSporadicSuppliesLoadResult(Map<String, Object> map);

   //获取达州钢铁内转实绩
    List<Map<String, Object>> getCgNzLoadingResult(Map<String, Object> mapVal);

    //获取装货实绩备注
    Map<String,Object> getInsertUpdateRemark(BigDecimal resultTotalId);

    //查找当前订单共有几次出
    List<Integer> allOutFactoryNum(BigDecimal orderId);

    //修改装货路段顺序号
    int updateSqe(@Param("orderId")BigDecimal orderId);

    //查询这个物资是否已经装过了
    Integer checkMaterialIdLoad(@Param("resultTotalId") BigDecimal resultTotalId,@Param("materialId") BigDecimal materialId);

    //通过钢材运输订单号查询装车实绩
    Map<String, Object> getSteelLoadResult(Map<String, Object> map);

    Map<String, Object> getLoadResultMap(BigDecimal resultTotalId);



}